@@ -8,15 +8,16 @@ __all__ = [
     '__version__',
     '__author__',
     '__email__',
-    '__license__',
-]
+    '__license__']
 
 __title__ = 'ladder'
-__summary__ = 'HTTP client wrapper with URL generation via object ' + \
-              'notation and argument passing'
+__summary__ = ('General purpose path generation library with support for '
+              'URLs, OS paths, delimited paths, and RESTful HTTP client '
+              'integration.')
+
 __url__ = 'https://github.com/dgilland/ladder'
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 __author__ = 'Derrick Gilland'
 __email__ = 'dgilland@gmail.com'
